@@ -4,14 +4,14 @@ import sys
 from dataclasses import dataclass
 
 from gpg_lite import deserialize
+
 # deserialize is shadowed by deserialize.deserialize:
 deserialize = sys.modules["gpg_lite.deserialize"]
 
 
 class TestDeserialize(unittest.TestCase):
     def test_dict_type(self):
-        self.assertEqual(deserialize.dict_type(
-            typing.Dict[int, str]), (int, str))
+        self.assertEqual(deserialize.dict_type(typing.Dict[int, str]), (int, str))
         self.assertEqual(deserialize.dict_type(int), None)
 
     def test_deserialize(self):
@@ -42,7 +42,5 @@ class TestDeserialize(unittest.TestCase):
         self.assertEqual(z, Z(a=1, dct=data["dct"]))
 
         # typing.Optional
-        self.assertEqual(deserialize.deserialize(
-            typing.Optional[int])(None), None)
-        self.assertEqual(deserialize.deserialize(
-            typing.Optional[int])(1), 1)
+        self.assertEqual(deserialize.deserialize(typing.Optional[int])(None), None)
+        self.assertEqual(deserialize.deserialize(typing.Optional[int])(1), 1)
