@@ -8,11 +8,12 @@ class TestParser(unittest.TestCase):
         seq = (1, 2, 3)
         self.assertEqual([seq], list(parser.expand_token_sequence(seq)))
         seq = ((1, 2), 2, 3)
-        self.assertEqual({(1, 2, 3), (2, 2, 3)}, set(
-            parser.expand_token_sequence(seq)))
+        self.assertEqual({(1, 2, 3), (2, 2, 3)}, set(parser.expand_token_sequence(seq)))
         seq = (1, (2, 3), (2, 3, 4))
-        self.assertEqual({(1, i, j) for i in (2, 3) for j in (2, 3, 4)}, set(
-            parser.expand_token_sequence(seq)))
+        self.assertEqual(
+            {(1, i, j) for i in (2, 3) for j in (2, 3, 4)},
+            set(parser.expand_token_sequence(seq)),
+        )
 
     def test_expand_token_sequences(self):
         seqs = {(0, 2, 3): 1, (1, (2, 3), (2, 3, 4)): 2}
